@@ -23,17 +23,16 @@ for my $i ( 1 .. 6 ) {
 }
 
 my $table = LaTeX::Table->new(
-    {   
-        maincaption => 'Price List',
+    {   maincaption => 'Price List',
         caption     => 'Try our special offer today!',
         size        => 'large',
-        callback  => sub {
-              my ($row, $col, $value, $is_header ) = @_;
-              if ($col == 2 && !$is_header) {
-                  $value = format_price($value, 2, '');
-              }
-              return $value;
-         },
+        callback    => sub {
+            my ( $row, $col, $value, $is_header ) = @_;
+            if ( $col == 2 && !$is_header ) {
+                $value = format_price( $value, 2, '' );
+            }
+            return $value;
+        },
     }
 );
 
@@ -69,14 +68,18 @@ foreach my $theme ( keys %{ $table->get_available_themes } ) {
     $table->set_header($test_header);
     $table->set_data($test_data);
     $table->generate();
-#    warn Dumper $test_data;
+
+    #    warn Dumper $test_data;
     $table->set_type('xtab');
-#    $table->set_caption_top(1);
+
+    #    $table->set_caption_top(1);
     $table->set_filename("${theme}multipage.tex");
     $table->set_xentrystretch(-0.1);
     $table->set_header($test_header);
     $table->set_data($test_data_large);
-    $table->set_caption_top('\setlength{\abovecaptionskip}{0pt}\setlength{\belowcaptionskip}{10pt}\topcaption');
+    $table->set_caption_top(
+        '\setlength{\abovecaptionskip}{0pt}\setlength{\belowcaptionskip}{10pt}\topcaption'
+    );
     $table->generate();
 }
 
@@ -87,16 +90,16 @@ foreach my $line (<DATA>) {
 my $code = << 'EOC'
 my $header = [ [ 'Character', 'Fullname', 'Voice' ], ];
 my $data = [
-    [ 'Homer', 'Homer Jay Simpson',               'Dan Castellaneta', ],
-    [ 'Marge', 'Marjorie Simpson (née Bouvier)', 'Julie Kavner', ],
-    [ 'Bart',  'Bartholomew Jojo Simpson',        'Nancy Cartwright', ],
-    [ 'Lisa',  'Elizabeth Marie Simpson',         'Yeardley Smith', ],
-    [   'Maggie',
-        'Margaret Simpson',
+    [ 'Homer',  'Homer Jay Simpson', 'Dan Castellaneta' ],
+    [ 'Marge',  'Marjorie Simpson (née Bouvier)', 
+        'Julie Kavner' ],
+    [ 'Bart',   'Bartholomew Jojo Simpson', 'Nancy Cartwright' ],
+    [ 'Lisa',   'Elizabeth Marie Simpson',  'Yeardley Smith' ],
+    [ 'Maggie', 'Margaret Simpson',
         'Elizabeth Taylor, Nancy Cartwright, James Earl Jones,'
-            . 'Yeardley Smith, Harry Shearer',
-    ],
+            . 'Yeardley Smith, Harry Shearer' ],
 ];
+
 $table = LaTeX::Table->new(
     {   header    => $header,
         data      => $data,
@@ -106,7 +109,7 @@ $table = LaTeX::Table->new(
 );
 
 EOC
-;
+    ;
 
 my $header = [ [ 'Character', 'Fullname', 'Voice' ], ];
 my $data = [
@@ -121,14 +124,14 @@ my $data = [
     ],
 ];
 $table = LaTeX::Table->new(
-    {   header    => $header,
-        data      => $data,
-        label     => 'wrap1',
-        caption   => 'LaTeX paragraph column attribute.',
+    {   header  => $header,
+        data    => $data,
+        label   => 'wrap1',
+        caption => 'LaTeX paragraph column attribute.',
     }
 );
 
-print ${OUT} "{\\tiny\\begin{lstlisting}\n$code\n\\end{lstlisting}}";
+print ${OUT} "{\\small\\begin{lstlisting}\n$code\n\\end{lstlisting}}";
 
 #$table->set_tabledef_strategy( { 'LONG_COL' => 'p{4cm}', 'IS_LONG' => 30 } );
 print ${OUT} $table->generate_string;
@@ -151,10 +154,9 @@ $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOC
-;
+    ;
 $table->set_label('wrap2');
-$table->set_caption(
-    'tabularx X column attribute.');
+$table->set_caption('tabularx X column attribute.');
 
 $table->set_width('0.9\textwidth');
 $table->set_width_environment('tabularx');
@@ -180,7 +182,7 @@ $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOC
-;
+    ;
 
 $table->set_environment('sidewaystable');
 $table->set_label('rotate');
@@ -208,19 +210,18 @@ $table->set_resizebox([ '300pt', '120pt' ]);
 \end{lstlisting}
 }
 EOC
-;
-
+    ;
 
 $table->set_environment('table');
 $table->set_label('resize');
-$table->set_resizebox([ '0.6\textwidth' ]);
-$table->set_caption( 'scaled to 60\% of the text width');
+$table->set_resizebox( ['0.6\textwidth'] );
+$table->set_caption('scaled to 60\% of the text width');
 
 print ${OUT} $code . $table->generate_string;
 
 $table->set_label('resize2');
-$table->set_resizebox([ '300pt', '120pt' ]);
-$table->set_caption( 'scaled to a size of 300pt x 120pt');
+$table->set_resizebox( [ '300pt', '120pt' ] );
+$table->set_caption('scaled to a size of 300pt x 120pt');
 print ${OUT} $table->generate_string;
 
 $code = << 'EOC'
@@ -241,7 +242,7 @@ $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOC
-;
+    ;
 my $test_header = [ [ 'Animal', 'Description', 'Price' ] ];
 $table = LaTeX::Table->new(
     {   header  => $test_header,
@@ -263,32 +264,32 @@ prices for Gnat are rounded in the following tables.
 \begin{lstlisting}
 
 my $header = [
-    [ ’Item:2c’, ’’ ],
-    [’\cmidrule(r){1-2}’],
-    [ ’Animal’, ’Description’, ’Price’ ]
+    [ 'Item:2c', '' ],
+    [ '\cmidrule(r){1-2}'],
+    [ 'Animal', 'Description', 'Price' ]
 ];
 
 my $data = [
-    [ ’Gnat’,      ’per gram’, ’13.651’  ],
-    [ ’’,          ’each’,      ’0.012’  ],
-    [ ’Gnu’,       ’stuffed’,  ’92.59’   ],
-    [ ’Emu’,       ’stuffed’,  ’33.33’   ],
-    [ ’Armadillo’, ’frozen’,    ’8.99’   ],
+    [ 'Gnat',      'per gram', '13.651'  ],
+    [ '',          'each',      '0.012'  ],
+    [ 'Gnu',       'stuffed',  '92.59'   ],
+    [ 'Emu',       'stuffed',  '33.33'   ],
+    [ 'Armadillo', 'frozen',    '8.99'   ],
 ];
 
 my $table = LaTeX::Table->new(
       {
-      filename    => ’prices.tex’,
-      maincaption => ’Price List’,
-      caption     => ’Try our special offer today!’,
-      label       => ’table:prices’,
-      position    => ’htb’,
+      filename    => 'prices.tex',
+      maincaption => 'Price List',
+      caption     => 'Try our special offer today!',
+      label       => 'table:prices',
+      position    => 'htb',
       header      => $header,
       data        => $data,
       callback    => sub {
            my ($row, $col, $value, $is_header ) = @_;
            if ($col == 2 && $!is_header) {
-               $value = format_price($value, 2, ’’);
+               $value = format_price($value, 2, '');
            }
            return $value;
      },
@@ -297,9 +298,9 @@ my $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOC
-;
+    ;
 
-print $OUT $code. "\\input{Zurich.tex}";
+print $OUT $code . "\\input{Zurich.tex}";
 
 $header = [
     [ 'Item:2c', '' ],
@@ -308,34 +309,33 @@ $header = [
 ];
 
 $data = [
-    [ 'Gnat',      'per gram', '13.651'   ],
-    [ '',          'each',      '0.012' ],
-    [ 'Gnu',       'stuffed',  '92.59'   ],
-    [ 'Emu',       'stuffed',  '33.33'   ],
-    [ 'Armadillo', 'frozen',    '8.99'   ],
+    [ 'Gnat',      'per gram', '13.651' ],
+    [ '',          'each',     '0.012' ],
+    [ 'Gnu',       'stuffed',  '92.59' ],
+    [ 'Emu',       'stuffed',  '33.33' ],
+    [ 'Armadillo', 'frozen',   '8.99' ],
 ];
 
 $table = LaTeX::Table->new(
-    {
-    filename    => 'prices.tex',
-    caption     => 'Try our special offer today!',
-    caption_top => 1,
-    label       => 'table:pricestop',
-    position    => 'htb',
-    header      => $header,
-    data        => $data,
-    callback    => sub {
-        my ($row, $col, $value, $is_header ) = @_;
-        if ($is_header) {
-            $value = uc $value;
-        }    
-        elsif ($col == 2 && !$is_header) {
-            $value = format_price($value, 2, '');
-        }
-        return $value;
-    },
-});
-
+    {   filename    => 'prices.tex',
+        caption     => 'Try our special offer today!',
+        caption_top => 1,
+        label       => 'table:pricestop',
+        position    => 'htb',
+        header      => $header,
+        data        => $data,
+        callback    => sub {
+            my ( $row, $col, $value, $is_header ) = @_;
+            if ($is_header) {
+                $value = uc $value;
+            }
+            elsif ( $col == 2 && !$is_header ) {
+                $value = format_price( $value, 2, '' );
+            }
+            return $value;
+        },
+    }
+);
 
 $code = << 'EOT';
 \subsection{Top Captions}
@@ -362,13 +362,13 @@ $table->set_caption_top(
 \end{lstlisting}
 }
 EOT
-;
 
 print $OUT $code . $table->generate_string();
-$table->set_caption_top('\setlength{\abovecaptionskip}{0pt}\setlength{\belowcaptionskip}{10pt}\caption');
+$table->set_caption_top(
+    '\setlength{\abovecaptionskip}{0pt}\setlength{\belowcaptionskip}{10pt}\caption'
+);
 $table->set_label('table:pricestop2');
 
-
 print $OUT $table->generate_string();
 
 $code = << 'EOT';
@@ -393,41 +393,39 @@ $table->set_theme('CENTRALPARK');
 \end{lstlisting}
 }
 EOT
-;
 
-$header = [
-    [ 'Item:2c', '' ],
-    [ 'Animal', 'Description', 'Price' ]
-];
+$header = [ [ 'Item:2c', '' ], [ 'Animal', 'Description', 'Price' ] ];
 
-$table->set_callback(sub {
-        my ($row, $col, $value, $is_header ) = @_;
-        if ($col == 2 && !$is_header) {
-            $value = format_price($value, 2, '');
+$table->set_callback(
+    sub {
+        my ( $row, $col, $value, $is_header ) = @_;
+        if ( $col == 2 && !$is_header ) {
+            $value = format_price( $value, 2, '' );
         }
         return $value;
-    });
+    }
+);
 
 $table->set_header($header);
 $table->set_theme('NYC');
 $table->set_caption_top(0);
 $table->set_label('table:customtheme1');
 
-print $OUT $code .  $table->generate_string() ;
+print $OUT $code . $table->generate_string();
 
 my $nyc_theme = $table->get_available_themes->{'NYC'};
-$nyc_theme->{'DEFINE_COLORS'}       = 
-          '\definecolor{latextablegreen}{RGB}{93,127,114}';
-$nyc_theme->{'HEADER_BG_COLOR'}     = 'latextablegreen';
-$nyc_theme->{'DATA_BG_COLOR_ODD'}   = 'latextablegreen!25';
-$nyc_theme->{'DATA_BG_COLOR_EVEN'}  = 'latextablegreen!10';
-$nyc_theme->{'EXTRA_ROW_HEIGHT'}    = '1pt';
+$nyc_theme->{'DEFINE_COLORS'}
+    = '\definecolor{latextablegreen}{RGB}{93,127,114}';
+$nyc_theme->{'HEADER_BG_COLOR'}    = 'latextablegreen';
+$nyc_theme->{'DATA_BG_COLOR_ODD'}  = 'latextablegreen!25';
+$nyc_theme->{'DATA_BG_COLOR_EVEN'} = 'latextablegreen!10';
+$nyc_theme->{'EXTRA_ROW_HEIGHT'}   = '1pt';
 
-$table->set_custom_themes({ CENTRALPARK => $nyc_theme });
+$table->set_custom_themes( { CENTRALPARK => $nyc_theme } );
 $table->set_theme('CENTRALPARK');
 $table->set_label('table:customtheme2');
 
-print $OUT  $table->generate_string() ;
+print $OUT $table->generate_string();
 
 $code = << 'EOT';
 \subsection{Multicolumns}
@@ -449,38 +447,36 @@ $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOT
-;
 
-$header = [ [ 'A:3c' ] , [ 'A:2c', 'B' ], ['A', 'B', 'C' ], ];
+$header = [ ['A:3c'], [ 'A:2c', 'B' ], [ 'A', 'B', 'C' ], ];
 $data = [ [ '1', 'w', 'x' ], [ '2', 'c:2c' ], ];
 
 $table = LaTeX::Table->new(
-    {   environment       => 1,
-        header            => $header,
-        data              => $data,
-        label             => 'table:mc',
-        caption           => 'Multicolumns made easy \dots',
-        theme             => 'Dresden',
+    {   environment => 1,
+        header      => $header,
+        data        => $data,
+        label       => 'table:mc',
+        caption     => 'Multicolumns made easy \dots',
+        theme       => 'Dresden',
     }
 );
 
 print $OUT $code . $table->generate_string();
 
 $data = [
-    [ 'Gnat',      'per gram', '13.651'   ],
-    [ '',          'each',      '0.012' ],
-    [ 'Gnu',       'stuffed',  '92.59'   ],
-    [ 'Emu',       'stuffed',  '33.33'   ],
-    [ 'Armadillo', 'frozen',    '8.99'   ],
+    [ 'Gnat',      'per gram', '13.651' ],
+    [ '',          'each',     '0.012' ],
+    [ 'Gnu',       'stuffed',  '92.59' ],
+    [ 'Emu',       'stuffed',  '33.33' ],
+    [ 'Armadillo', 'frozen',   '8.99' ],
 ];
 
 $table = LaTeX::Table->new(
-    {
-    caption     => 'Headers are not mandatory',
-    label       => 'table:noheader',
-    data        => $data,
-});
-
+    {   caption => 'Headers are not mandatory',
+        label   => 'table:noheader',
+        data    => $data,
+    }
+);
 
 $code = << 'EOT';
 \subsection{Headers}
@@ -502,12 +498,11 @@ $table = LaTeX::Table->new(
 \end{lstlisting}
 }
 EOT
-;
 
 print $OUT $code . $table->generate_string();
 
 $table->set_theme('NYC');
-$table->set_columns_like_header([0]);
+$table->set_columns_like_header( [0] );
 $table->set_label('table:collikeheader');
 $table->set_caption('We can format columns with the theme header definition');
 
@@ -518,88 +513,87 @@ $table->set_header($header);
 
 print $OUT $table->generate_string();
 
-$header = [ [ 'Time', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday' ] ];
+$header
+    = [ [ 'Time', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday' ] ];
 
-$data = [ 
-[ '9.00', '','', '', '', '', ],
-[ '10.00', '','', '', '', '', ],
-[ '11.00', '','', '', '', '', ],
-[ '12.00', '','', '', '', '', ],
+$data = [
+    [ '9.00',  '', '', '', '', '', ],
+    [ '10.00', '', '', '', '', '', ],
+    [ '11.00', '', '', '', '', '', ],
+    [ '12.00', '', '', '', '', '', ],
 ];
 
 $table = LaTeX::Table->new(
-    {   
-        header            => $header,
-        data              => $data,
-        label             => 'table:headersideways',
-        caption           => 'Header sideways',
-        header_sideways   => 1,
-        theme             => 'NYC',
+    {   header          => $header,
+        data            => $data,
+        label           => 'table:headersideways',
+        caption         => 'Header sideways',
+        header_sideways => 1,
+        theme           => 'NYC',
     }
 );
 
 print $OUT $table->generate_string();
 
 $table = LaTeX::Table->new(
-    {   
-        header            => $header,
-        data              => $data,
-        label             => 'table:headersideways2',
-        caption           => 'Header sideways',
+    {   header          => $header,
+        data            => $data,
+        label           => 'table:headersideways2',
+        caption         => 'Header sideways',
         header_sideways => 0,
-        callback => sub {
+        callback        => sub {
             my ( $row, $col, $value, $is_header ) = @_;
             if ( $col != 0 && $is_header ) {
                 $value = '\begin{sideways}' . $value . '\end{sideways}';
             }
             return $value;
         },
-        theme             => 'NYC',
+        theme => 'NYC',
     }
 );
 
 print $OUT $table->generate_string();
 
-$header = [ [ 'Website', 'URL' ] ];
-
-$data = [
-    [ 'Slashdot',    'http://www.slashdot.org'  ],
-    [ 'Perlmonks', '  http://www.perlmonks.org' ],
-    [ 'Google',      'http://www.google.com'    ],
-];
-
 $table = LaTeX::Table->new(
-    {
-    caption     => 'Some websites',
-    label       => 'table:website',
-    data        => $data,
-    header      => $header,
-    coldef_strategy => { 
-        URL     => qr{ \A \s* http }xms,
-        URL_COL => '>{\ttfamily}l',
-    }    
-});
-
+    {   caption => 'Some websites',
+        label   => 'table:website',
+        header  => [ [ 'Website', 'URL' ] ],
+        data    => [
+            [ 'Slashdot',  'http://www.slashdot.org' ],
+            [ 'Perlmonks', '  http://www.perlmonks.org' ],
+            [ 'Google',    'http://www.google.com' ],
+        ],
+        coldef_strategy => {
+            URL     => qr{ \A \s* http }xms,
+            URL_COL => '>{\ttfamily}l',
+        }
+    }
+);
 
 $code = << 'EOT';
 \subsection{Automatic column definitions}
-Table~\ref{table:website}.
-\newcolumntype{U}{>{\ttfamily}{l}}
+We can easily provide regular expressions that define the alignment of
+columns. See Table~\ref{table:website}.
 \small
 \begin{lstlisting}
 $table = LaTeX::Table->new(
-    {
-    data        => $data,
-    header      => $header,
-    coldef_strategy => { 
-        URL     => qr{ \A \s* http }xms,
-        URL_COL => '>{\ttfamily}l',
-    }    
-});
+    {   caption => 'Some websites',
+        label   => 'table:website',
+        header  => [ [ 'Website', 'URL' ] ],
+        data    => [
+            [ 'Slashdot',  'http://www.slashdot.org' ],
+            [ 'Perlmonks', 'http://www.perlmonks.org' ],
+            [ 'Google',    'http://www.google.com' ],
+        ],
+        coldef_strategy => {
+            URL     => qr{ \A \s* http }xms,
+            URL_COL => '>{\ttfamily}l',
+        }
+    }
+);
 \end{lstlisting}
 
 EOT
-;
 
 print $OUT $code . $table->generate_string();
 
@@ -615,7 +609,6 @@ first and second column is left justified because these columns contain only
 strings, whereas the third column is a number column and therefore right
 justified.
 EOT
-;
 
 print $OUT $code;
 
@@ -636,7 +629,7 @@ __DATA__
 \usepackage{rotating}
 \usepackage{tabularx}
 \usepackage{listings}
-\usepackage{color}
+%\usepackage{color}
 \usepackage{colortbl}
 \usepackage{xcolor}
 \usepackage{graphicx}
